function [fmr,fnmr,EER] = CreateDET(dtwpairs)
% Description:
%       This function finds the Equal Error Rate (eer) from the DTW
%       pairwise distance matrix produced by dtw_pairdistance, along with
%       the False Match Rate and False Non-Match Rate. Also provides a
%       plot.
% Input:
%       dtwpairs - a matrix where cell (i,j) represents the DTW
%       distance between person i and person j.
% Output:
%       EER - equal error rate (double)
%       fmr - false match rate (double)
%       fnmr - false non-match rate (double)
%
% Authors:
%       Patrick Bours, 2009
%       Gjvik University College, HiG
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.

%Holders
genuine     = [];
impostor    = [];

%Append to the vectors.
for i=1:50
    for j=1:50
        if (i==j)
            genuine=[genuine,dtwpairs(i,j)];
        else
            impostor=[impostor,dtwpairs(i,j)];
        end
    end
end

%Find minimums and maximums
minima = min(min(genuine),min(impostor));
maxima = max(max(genuine),max(impostor));

%Holders
fmr=[];
fnmr=[];

global thresholds;  
thresholds=sort([genuine,impostor]);

%Try for different tresholds
for i=1:(length(thresholds))
    t=thresholds(i);
    fmr=[fmr,sum(impostor<=t)];
    fnmr=[fnmr,sum(genuine>t)];
end
fmr=fmr/length(impostor);
fnmr=fnmr/length(genuine);

%Find EER
i=1;
while (fmr(i)<fnmr(i))
    i=i+1;
end

i=i-1;

if (fmr(i)==fnmr(i))
    EER=fmr(i);
else
    EER=(fmr(i)+fmr(i+1)+fnmr(i)+fnmr(i+1))/4;
end

plot(fmr,fnmr,'black');