function [meanavg,medianavg,trimmedmeanavg] = average_cycle(normalizedcycles)
% Description:
%       This function takes input from the normalize_cycles function, and
%       produces an average cycle for a few different averaging tools.
% Input:
%       normalizedcycles - complete cycle data, normalized to equal
%       lengths. The rows in the table represent gait cycles, and the
%       columns represent resultant values. Size example: 20 x 110
% Output:
%       meanavg - the average cycle computed by mean
%       medianavg - the average cycle computed by mean
%       trimmedmeanavg - the average cycle computed by mean
% Author:
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.

%Skip irregular cycles
normalizedcycles = omit_cycles(normalizedcycles);

%Sort every column
normalizedcycles = sort(normalizedcycles);

medianavg = median(normalizedcycles);
meanavg   = mean(normalizedcycles);
trimmedmeanavg = trimmean(normalizedcycles,5);
