function [gdir] = convert_to_g(xdir)
% Description:
%        This function computes g-forces from the raw MR100 data. The
%        constants used are prone to changes, and should be calibrated in
%        new experiments.
% Input:
%       xdir - raw acceleration values in three dimentions (three-column
%       table).
% Output:
%       gdir - three-column table with g-forces corresponding to xdir.
%
% Author:
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.

gdir = zeros(length(xdir),3);

%Calculate resultant by%Convert to G-forces. Constants are specific to the MR100 1005
%device.
%My own for the -1 sensor.
XUp   = 591;
XDown = 509;
YUp   = 590;
YDown = 514;
ZUp   = 576;
ZDown = 495;

%My own for the 1005 sensor. These are good
% XUp   = 604;
% XDown = 472;
% YUp   = 606;
% YDown = 470;
% ZUp   = 604;
% ZDown = 470;
%Holien 1005
% XUp   = 596;
% XDown = 498;
% YUp   = 597;
% YDown = 505;
% ZUp   = 581;
% ZDown = 487;
%Holien 3005
% XUp     = 590;
% YUp     = 586;
% ZUp     = 584;
% XDown   = 499;
% YDown   = 491;
% ZDown   = 488;
XStep   = (XUp - XDown) / 2;
YStep   = (YUp - YDown) / 2;
ZStep   = (ZUp - ZDown) / 2;

%Convert values
gdir(:,1) = (xdir(:,1) - (XDown + XStep)) / XStep;
gdir(:,2) = (xdir(:,2) - (YDown + YStep)) / YStep;
gdir(:,3) = (xdir(:,3) - (ZDown + ZStep)) / ZStep;
