function [amount] = createtemplates(folder)
% Description
%       This function will find all walks in a folder, given that their filenames
%       start with walk, and produce templates corresponding to each file.
% Input:
%       folder - folder containing raw data.
% Output:
%       None. Templates are created in the corresponding subfolder and
%       named t_[originalname].dat.
%
% Author:
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.

%We only want walks
query  = strcat(folder,'/walk*.dat');
%Fetch walk info
list   = dir(query);
amount = length(list);

%For storing templates
templatefolder = strcat(folder,'');

%For all walks found
for i=1:amount
   %Fetch one walk, preprocess and get average cycle
   path                         = strcat(folder,'/',list(i).name);
   [gaitdata, time, resultant]  = preprocess(path);
   cycles                       = detect_cycles(time,resultant);
   normalizedcycles             = normalize_cycles(cycles,resultant);
   average                      = average_cycle(normalizedcycles);
   
   %Save average as template (typically Templates/t_walk1_name.dat)
   path                         = strcat(templatefolder,'/t_',list(i).name);
   save(path,'average','-ASCII');
end



