function [cycles] = detect_cycles(time,resultant)
% Description:
%       This function finds cycles in a gait signal and returns the index
%       values of where the cycles start, and the resultant values at that
%       position.
% Input:
%       time - a one-column table (array) with time values
%       resultant - acceleration amplitudes corresponding to time
% Output:
%       cycles - a two-column table with cycle starting indexes in the
%       first column, and the resultant at this position.
%
% Author:
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.


%Estimate average length of the cycles
cycle_length = estimate_cyclelength(time,resultant);

%Determine a starting location by looking for a minimum in the middle.
%A window will be checked for a maximum, and the search will start from
%there.
middle      = floor(length(time)/2);
%Buffer to find the middle minimum
startwindow = round(1.2 * cycle_length);
startindex  = 0;
min         = realmax;
%Determine the minimum and make it the search start location
for i = (middle - startwindow) : (middle + startwindow)
    if (resultant(i,1) < min)
        min = resultant(i,1);
        startindex = i;
    end
end

%SEARCH
currentposition = startindex;
minima          = zeros(length(resultant),1);
cyclecounter    = 0;

%FORWARD search
%Check index out of bound
while(currentposition < (length(resultant) - 10))
    %Reset holders
    min       = resultant(currentposition,1);
    minindex  = currentposition;
    %Search current location +- 10 samples
    for i = (currentposition - 10) : (currentposition + 10)
        if (resultant(i,1) < min)
            min      = resultant(i,1);
            minindex = i;
        end
    end
    
    %Minimum now found in a window of 20, minindex
    %pointing to minimum index. Store in minima array.
    %Proceed to the next step
    minima(minindex,1)  = min;
    currentposition     = minindex + cycle_length;
    cyclecounter        = cyclecounter + 1;
end


%BACKWARD search
currentposition         = startindex - cycle_length;
%Check index out of bound
while(currentposition > 10)
    %Reset holders
    min       = resultant(currentposition,1);
    minindex  = currentposition;
    %Search current location +- 10 samples
    for i = (currentposition - 10) : (currentposition + 10)
        if (resultant(i,1) < min)
            min      = resultant(i,1);
            minindex = i;
        end
    end
    
    %Minimum now found in a window of 20, minindex
    %pointing to minimum index. Store in minima array.
    %Proceed to the next step
    minima(minindex,1)  = min;
    currentposition     = minindex - cycle_length;
    cyclecounter        = cyclecounter + 1;
end

%Done searching, organize findings
cycles = zeros(cyclecounter,2);
pointer = 1;

%Look for non-zero values in minima, store in the list of cycles.
for i = 1:length(minima)
    if(minima(i,1) ~= 0)
        cycles(pointer,1) = i;
        cycles(pointer,2) = minima(i,1);
        %Point to next free spot in cycle list
        pointer = pointer + 1;        
    end
end












