function [dtw_distance, costmatrix] =  dtw(sequenceA,sequenceB)
% Description:
%       This function calculates the Dynamic Time Warping distance between
%       two sequences. The algorithm is a modified version of the
%       original DTW, with constant costs for insertion and deletion.
% Input:
%       sequenceA - a gait cycle vector
%       sequenceB - a gait cycle vector
% Output:
%       dtw_distance - the  DTW distance after comparing shifts.
%
% Author:
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.

c_del = 0.5;
c_ins = 0.5;

%Cost matrix holder
costmatrix = zeros(length(sequenceA)+1,length(sequenceB)+1);

%Find maximum set distance (used for c_sub)
S = max(max(sequenceA),max(sequenceB)) - min(min(sequenceA),min(sequenceB));

%Boundary conditions
costmatrix(1,1) = 0.00;

%First column
for i = 2:length(costmatrix(:,1))
   costmatrix(i,1) = costmatrix(i-1,1) + c_del;
end

%First row
for j = 2:length(costmatrix(1,:))
   costmatrix(1,j) = costmatrix(1,j-1) + c_ins;
end

%The rest of the matrix
for i = 2:length(costmatrix(:,1))
    for j = 2:length(costmatrix(1,:))
       %Fetch value for replacement
       x = sequenceA(1,i-1);
       %Fetch new value
       y = sequenceB(1,j-1);
       %Calculate substitution cost
       c_sub = abs(x - y) / S;
       %Find best path
       costmatrix(i,j) = min([(costmatrix(i-1,j-1) + c_sub), (costmatrix(i-1,j) + c_del), (costmatrix(i,j-1) + c_ins)]);
    end   
end

dtw_distance = costmatrix(end,end);