function [attack_dtwmatrix, a_cyclelengths,v_cyclelengths] = dtw_attack(victimfolder,attackfolder)
% Description:
%       This function compares templates of two specific folder. Used to
%       "attack" a victim by comparing the attackers templates with those
%       of the victim. Produces a DTW matrix with attacker rows and victim
%       columns.
% Input:
%       victimfolder - folder containing the victim templates
%       attackfolder - folder containing the attacker templates
% Output:
%       attack_dtwmatrix - (i,j) in this matrix represent the DTW distance
%       between attacker's template i and victim template j.
%       a_cyclelengths - cycle lengths of attacker templates
%       v_cyclelengths - cycle lengths of victim templates
%       The latter two are used for attacker feedback (walk speed etc).
%
% Author:
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.


%Get victim data
vquery  = strcat(victimfolder,'/t_*.dat');
vfiles   = dir(vquery);
vamount = length(vfiles);

%Get attacker data
vquery  = strcat(attackfolder,'/t_*.dat');
afiles   = dir(vquery);
aamount = length(afiles);

%Holders and settings for DTW, and cyclelengths
attack_dtwmatrix = zeros(aamount,vamount);
a_cyclelengths = zeros(aamount,1);
v_cyclelengths = zeros(vamount,1);

%Open / create / append to filename text file
% datetime  = datestr(now);
% afilenames = fopen(strcat(attackfolder,'/attacker_filenames.txt'),'w');
% vfilenames = fopen(strcat(victimfolder,'/victim_filenames.txt'),'w');
% fprintf(afilenames,['---',datetime,'---']);
% fprintf(vfilenames,['---',datetime,'---']);
% fprintf(afilenames,'\r\n');
% fprintf(vfilenames,'\r\n');
% fprintf(afilenames,'These files represent rows in the DTW attack matrix.');
% fprintf(vfilenames,'These files represent columns in the DTW attack matrix.');
% fprintf(afilenames,'\r\n');
% fprintf(vfilenames,'\r\n');

%Load all templates found to matlab
for i=1:vamount   
   load(strcat(victimfolder,'/',vfiles(i).name));
   v_cyclelengths(i,1) = length(eval(vfiles(i).name(1,1:end-4)));
end
for i=1:aamount   
   load(strcat(attackfolder,'/',afiles(i).name));
   a_cyclelengths(i,1) = length(eval(afiles(i).name(1,1:end-4)));
end

% for j = 1:vamount
%     %Append filename to list
%     fprintf(vfilenames,strcat(int2str(j),':',vfiles(j).name(1,1:end-4)));
%     fprintf(vfilenames,'\r\n');
% end

%Calculate DTW matrix and store names in the text file
%Row loop
for i = 1:aamount
    %Append filename to list
%     fprintf(afilenames,strcat(int2str(i),':',afiles(i).name(1,1:end-4)));
%     fprintf(afilenames,'\r\n');
    %Column loop. Only one half is necessary, so j = i.
    for j = 1:vamount
        %Calculate DTW
        attack_dtwmatrix(i,j) = dtw_min(eval(afiles(i).name(1,1:end-4)),eval(vfiles(j).name(1,1:end-4)));        
    end
end

%Close file
% fprintf(vfilenames,'----------End----------');
% fprintf(afilenames,'----------End----------');
% fprintf(vfilenames,'\r\n\r\n');
% fprintf(afilenames,'\r\n\r\n');
% fclose(vfilenames);
% fclose(afilenames);

path                         = strcat(attackfolder,'/attack_dtwmatrix');
save(path,'attack_dtwmatrix');