function [dtwmatrix,files] = dtw_matrix(templatefolder,shifting_boolean)
% Description:
%       This function computes a matrix showing the DTW distnace between
%       all persons found in templatefolder.
% Input:
%       templatefolder - the folder containing templates. Templates must be
%       named starting with t_ and ending with .dat (e.g. t_walk01.dat).
%       shifting_boolean - a binary value. If set to 1, shifting will be
%       used to determine minimal DTW distance. If set to 0, only the
%       original DTW will be used.
% Output:
%       dtwmatrix - a matrix where cell (i,j) represent the DTW distance
%       between person i and person j.
%       files - a file list over templates. Mostly unused.
%
% Author:
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.

%We only want templates
query  = strcat(templatefolder,'/t_*.dat');
%Fetch template info
files   = dir(query);
amount = length(files);

%Holders and settings for DTW
dtwmatrix = zeros(amount,amount);

%Open / create / append to filename text file
datetime  = datestr(now);
filenames = fopen(strcat(templatefolder,'/filenames.txt'),'a');
fprintf(filenames,['---',datetime,'---']);
fprintf(filenames,'\r\n');

%Load all templates found to matlab
for i=1:amount
    load(strcat(templatefolder,'/',files(i).name));
end

%Calculate DTW matrix and store names in the text file
%Row loop
for i = 1:amount
    %Append filename to list
    fprintf(filenames,strcat(int2str(i),':',files(i).name(1,1:end-4)));
    fprintf(filenames,'\r\n');
    %Column loop. Only one half is necessary, so j = i.
    for j = i:amount
        %Calculate DTW
        if(shifting_boolean == 0)
            dtwmatrix(i,j) = dtw(eval(files(i).name(1,1:end-4)),eval(files(j).name(1,1:end-4)));
        else
            dtwmatrix(i,j) = dtw_min(eval(files(i).name(1,1:end-4)),eval(files(j).name(1,1:end-4)));
        end
    end
end

%Close file
fprintf(filenames,'----------End----------');
fprintf(filenames,'\r\n\r\n');
fclose(filenames);

%Finalize matrix and store. Adding the transposition mirrors the matrix
%diagonally, completing the whole table. This is not a necessity, but a
%conveinience.
dtwmatrix                    = dtwmatrix + transpose(dtwmatrix);
path                         = strcat(templatefolder,'/dtwmatrix',templatefolder(1,end-3:end));
save(path,'dtwmatrix');













