function [cyclelength] = estimate_cyclelength(time,resultant)
% Description:
%       This function finds an average cycle length from a a gait signal.
% Input:
%       time - a one-column table (array) with time values
%       resultant - acceleration amplitudes corresponding to time
% Output:
%       cyclelength - an estimated average cycle length (integer)
%
% Author:
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.


% Experimental values. width: how many samples to include in a subgraph
% search. Threshold: required correlation to assume a cycle match.
% These have been found in the following way: 10 gait
% WALKS are tested towards values of width and threshold, and the
% combination yielding the most stable results are chosen. Then the values
% are tested against the whole gait set, and this process is repeated
% untill a satisfactory result is obtained from the large set.
width = 90;
threshold = 0.83;

%Take _width_ samples from the middle to make subgraph
start_pos    = floor(3*length(time)/4);
stop_pos     = start_pos + (width-1);
subgraph     = resultant(start_pos:stop_pos,1);
min_distance = 80;

%For remembering high correlations
high_correlations = zeros(start_pos,1);

%Go left to find high correlations, from middle to 1/4 of the length
for i = (start_pos - min_distance):-1:round(length(time)/4)
    tempgraph = resultant(i:(i+length(subgraph)-1));
    correlation = corr(subgraph,tempgraph);
    %Is the correlation above the threshold? Remember
    if correlation >= threshold
        high_correlations(i,1) = correlation;
    end
end

%Find correlation maximums to narrow the vector down to
%starting locations for the subgraph. The distance between these
%are cycle distances.
[maxtab] = peakdet(transpose(high_correlations),0.001);

%Calculate average distances based on all cycles found, and return it
cyclelength = pairdistance(transpose(maxtab(:,1)));