function [time,dir] = interpolate1(time,dir)
% Description:
%       This function interpolates raw data such that the time axis of gait
%       data is equal.
% Input:
%       time - a one-column table (array) with time values, raw
%       dir - acceleration amplitudes corresponding to time, in three
%       directions.
% Output:
%       time - a one-column table (array) with time values, interpolated
%       dir - acceleration amplitudes corresponding to time, in three
%       directions.
%
% Author:
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.

%Get each column as a vector
x = transpose(dir(:,1));
y = transpose(dir(:,2));
z = transpose(dir(:,3));

%Arrange observed time values and desired steps
%time(1,1)  = floor(time(1,1)*100) / 100;
time       = time - time(1,1);
steps      = time(1,1):0.01:time(length(time),1);
ttime      = transpose(time);

%Perform interpolation
ix         = interp1(ttime,x,steps);
iy         = interp1(ttime,y,steps);
iz         = interp1(ttime,z,steps);

xdir = zeros(length(steps),1);
%Arrange results
xdir(:,1) = ix(1,:);
xdir(:,2) = iy(1,:);
xdir(:,3) = iz(1,:);
dir = xdir;

time = transpose(steps);