function [avgdistance, maxlength] = pairdistance(values)
% Description:
%       This function takes a vector of observed possible cycle starting
%       points, and produces an average cycle length estimate.
% Input:
%       values - vector of cycle starting points, for instance produced by
%       detect_cycles.
% Output:
%       avgdistance - average distance between cycles (integer)
%       maxlength - maximal cycle length (integer)
%
% Author:
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.

%For total value
sum              = 0;
%For hidden cycles. For instance if two cycles are interpreted as one
hidden           = 0;
currently_hidden = 0;

%For determining the max length of a cycle
maxlength        = -realmax;


for i = 1:length(values)-1
    %Find cycle length entries
    temp = (values(1,i+1) - values(1,i));
    
    %Could there be n cycles hidden in temp?
    for n = 2:10
        if(((temp / n) > 90) && ((temp / n) < 130))
            %n cycles found
            hidden           = hidden + n - 1;
            currently_hidden = n;
            break;
        end
    end
    %If the cycle is even longer or shorter, skip it
    if((temp / 10) > 130 || temp < 80)
        hidden = hidden - 1;
        continue;
    end   
    
    %Add to total
    sum  = sum + temp;
    
    %Update max. Take hidden cycles into consideration
    if(currently_hidden ~= 0)
        temp = ceil(temp/currently_hidden);
        currently_hidden = 0;
    end
    if(maxlength < temp)
        maxlength = temp;
    end
end

%Calculate the average. If cycles are hidden, these must be accounted for.
avgdistance = round(sum / (length(values) - 1 + hidden));