function [gaitdata, time, resultant] = preprocess(fname)
% Description:
%       This function applies basic preprocessing to raw data supplied by
%       the MR100 accelerometer.
% Input:
%       fname - filename of gait sequence
% Output:
%       time - a one-column table (array) with time values
%       resultant - acceleration amplitudes corresponding to time
%       gaitdata - a two-column table with both time and resultant
%
% Author:
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.

%Read from file. Null is unused lable holder.
[null,xtime,xdir] =  readColData(fname,4,10,0);

%INTERPOLATE to obtain data table with equal time values and corresponding
%resultant values. This will also update vectors and preprocessing is done.
[time,xdir] = interpolate1(xtime,xdir);

%With interpolated values we can remove noise.
%Apply WMA filter. Time is included because start and beginning is cut.
[time,dir] = wma(time, xdir);

%CONVERT to G-forces
dir = convert_to_g(dir);

% RESULTANT taking the root of a^2 + b^2 + c^2
resultant = get_resultant(dir);

gaitdata  = zeros(length(resultant),2);
%Gather into xgaitdata before interpolation
for i = 1:length(resultant)
    gaitdata(i,1) = time(i,1); %Fill with time values (4 off)
    gaitdata(i,2) = resultant(i,1); %Fill with resultant values
end

