function [time, dir] = wma(xtime, xdir)
% Description:
%       This function applies a Weighted Moving Average filter to acceleration
%       data provided by the MR100 accelerometer.
% Input:
%       normalizedcycles - complete cycle data, normalized to equal
%       lengths. The rows in the table represent gait cycles, and the
%       columns represent resultant values. Size example: 20 x 110
% Output:
%       meanavg - the average cycle computed by mean
%       medianavg - the average cycle computed by mean
%       trimmedmeanavg - the average cycle computed by mean
% Author:
%       Bendik B. Mjaaland, 2009
%       Norwegian University of Science and Technology (NTNU)
%       
% Disclaimer:
%       This piece of software is not copyrighted, and anyone are free to
%       use it in any context as long as the author information and
%       disclaimer is preserved.


dir        = zeros(length(xdir)-4,3);

%Apply WMA filter, equivalent to wma(5)
%WMA for X direction
for i = 3:(length(xdir)-2)
    dir(i-2,1) = (xdir(i-2,1) + 2 * xdir(i-1,1) + 3 * xdir(i,1,1) + 2 * xdir(i+1,1) + xdir(i+2,1)) / 9;
end
%WMA for Y direction
for i = 3:(length(xdir)-2)
    dir(i-2,2) = (xdir(i-2,2) + 2 * xdir(i-1,2) + 3 * xdir(i,2) + 2 * xdir(i+1,2) + xdir(i+2,2)) / 9;
end
%WMA for Z direction
for i = 3:(length(xdir)-2)
    dir(i-2,3) = (xdir(i-2,3) + 2 * xdir(i-1,3) + 3 * xdir(i,3) + 2 * xdir(i+1,3) + xdir(i+2,3)) / 9;
end

time = zeros(length(xtime)-4,1);
for i=1:length(dir)
    time(i,1) = xtime(i+2,1);
end